MapCodable<K, V> class

A Codable that can encode and decode a map of K and V.

Prefer using AsMapCodable.map instead of the constructor.

Implemented types

Constructors

MapCodable(Codable<K>? keyCodable, Codable<V> codable)
const

Properties

codable → Codable<V>
final
hashCode → int
The hash code for this object.
no setterinherited
keyCodable → Codable<K>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(Decoder decoder) → Map<K, V>
Decodes a value of type T using the decoder.
override
decodeKeyed(KeyedDecoder keyed) → Map<K, V>
encode(Map<K, V> value, Encoder encoder) → void
Encodes the value using the encoder.
override
extract<R>(R fn<A, B>(Codable<A>? codableA, Codable<B>? codableB)) → R
Extracts the child Decodables for the type parameters A and B from the composed Decodable for type T<A, B>.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited