MapSelfEncodable<T extends SelfEncodable> class

An Encodable that can encode a map of K and T.

Prefer using AsMapEncodable.encode instead of the constructor.

Implemented types
Available extensions

Constructors

MapSelfEncodable(Map<dynamic, T> value)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → Map<dynamic, T>
final

Methods

encode(Encoder encoder) → void
Encodes itself using the encoder.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCsv() → String

Available on T, provided by the CsvSelfEncodableSelf extension

toCsvBytes() → List<int>

Available on T, provided by the CsvSelfEncodableSelf extension

toJson() → String

Available on T, provided by the JsonSelfEncodableSelf extension

toJsonBytes() → List<int>

Available on T, provided by the JsonSelfEncodableSelf extension

toMap() → Map<String, dynamic>

Available on T, provided by the StandardSelfEncodable extension

toMsgPack() → List<int>

Available on T, provided by the MsgPackSelfEncodableSelf extension

toProgressiveJson() → List<int>

Available on T, provided by the ProgressiveJsonSelfEncodableSelf extension

toProgressiveJsonStream() → Stream<List<int>>

Available on T, provided by the ProgressiveJsonSelfEncodableSelf extension

toString() → String
A string representation of this object.
inherited
toValue() → Object?

Available on T, provided by the StandardSelfEncodable extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited