AsyncMappedDecoder extension

on

Methods

decodeFuture<T>(String key, {int? id, Decodable<T>? using}) → Future<T>

Available on MappedDecoder, provided by the AsyncMappedDecoder extension

Decodes a Future of T using the provided Decodable.
decodeFutureOrNull<T>(String key, {int? id, Decodable<T>? using}) → Future<T>?

Available on MappedDecoder, provided by the AsyncMappedDecoder extension

Decodes a Future of T or null using the provided Decodable.
decodeStream<T>(String key, {int? id, Decodable<T>? using}) → Stream<T>

Available on MappedDecoder, provided by the AsyncMappedDecoder extension

Decodes a Stream of T using the provided Decodable.
decodeStreamOrNull<T>(String key, {int? id, Decodable<T>? using}) → Stream<T>?

Available on MappedDecoder, provided by the AsyncMappedDecoder extension

Decodes a Stream of T or null using the provided Decodable.