Reference<T> class sealed

Constructors

Reference(T value, {Encodable<T>? using})
factory
Reference.late({Encodable<T>? using})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sentinel → Object?
no setter
using → Encodable<T>?
no setter

Methods

get<R>(R callback(T value)) → Reference<R>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(T value) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited