NullableJsonConsumer<T> class

Implemented types

Constructors

NullableJsonConsumer(LazyIteratedDecoder parent, void onValue(T? value), Decodable<T>? using)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isDone → bool
no setteroverride
onValue → void Function(T? value)
final
parent → LazyIteratedDecoder
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
using → Decodable<T>?
final

Methods

add(List<int> data, int offset) → int
override
close() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited