StandardMappedDecoder class

Implemented types
Available extensions

Constructors

StandardMappedDecoder(Map<Object, dynamic> _value, [bool _isHumanReadable = true, List<CustomTypeDelegate> _customTypes = const []])

Properties

hashCode → int
The hash code for this object.
no setterinherited
keys → Iterable<Object>
Returns the keys (or ids) of the collection.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decodeBool(String key, {int? id}) → bool
Decodes the data for the given key or id as a boolean value.
override
decodeBoolOrNull(String key, {int? id}) → bool?
Decodes the data for the given key or id as a nullable boolean value.
override
decodeDouble(String key, {int? id}) → double
Decodes the data for the given key or id as a double value.
override
decodeDoubleOrNull(String key, {int? id}) → double?
Decodes the data for the given key or id as a nullable double value.
override
decodeFuture<T>(String key, {int? id, Decodable<T>? using}) → Future<T>

Available on MappedDecoder, provided by the AsyncMappedDecoder extension

Decodes a Future of T using the provided Decodable.
decodeFutureOrNull<T>(String key, {int? id, Decodable<T>? using}) → Future<T>?

Available on MappedDecoder, provided by the AsyncMappedDecoder extension

Decodes a Future of T or null using the provided Decodable.
decodeInt(String key, {int? id}) → int
Decodes the data for the given key or id as an integer value.
override
decodeIntOrNull(String key, {int? id}) → int?
Decodes the data for the given key or id as a nullable integer value.
override
decodeIsNull(String key, {int? id}) → bool
Checks if the data for the given key or id is null.
override
decodeIterated(String key, {int? id}) → IteratedDecoder
Decodes the data for the given key or id as an iterated collection of nested data.
override
decodeKeyed(String key, {int? id}) → KeyedDecoder
Decodes the data for the given key or id as a iterated collection of key-value pairs of nested data.
override
decodeList<E>(String key, {int? id, Decodable<E>? using}) → List<E>
Decodes the data for the given key or id as a list of elements.
override
decodeListOrNull<E>(String key, {int? id, Decodable<E>? using}) → List<E>?
Decodes the data for the given key or id as a nullable list of elements.
override
decodeMap<K, V>(String key, {int? id, Decodable<K>? keyUsing, Decodable<V>? valueUsing}) → Map<K, V>
Decodes the data for the given key or id as a map of key-value pairs.
override
decodeMapOrNull<K, V>(String key, {int? id, Decodable<K>? keyUsing, Decodable<V>? valueUsing}) → Map<K, V>?
Decodes the data for the given key or id as a nullable map of key-value pairs.
override
decodeMapped(String key, {int? id}) → MappedDecoder
Decodes the data for the given key or id as a direct-access collection of key-value pairs of nested data.
override
decodeNum(String key, {int? id}) → num
Decodes the data for the given key or id as a num value.
override
decodeNumOrNull(String key, {int? id}) → num?
Decodes the data for the given key or id as a nullable num value.
override
decodeObject<T>(String key, {int? id, Decodable<T>? using}) → T
Decodes the data for the given key or id as an object of type T.
override
decodeObjectOrNull<T>(String key, {int? id, Decodable<T>? using}) → T?
Decodes the data for the given key or id as a nullable object of type T.
override
decodeReference<T>(String key, {int? id, Decodable<T>? using}) → Reference<T>

Available on MappedDecoder, provided by the ReferenceMappedDecoder extension

Decodes a Reference of T using the provided Decodable.
decodeReferenceOrNull<T>(String key, {int? id, Decodable<T>? using}) → Reference<T>?

Available on MappedDecoder, provided by the ReferenceMappedDecoder extension

Decodes a Reference of T or null using the provided Decodable.
decodeStream<T>(String key, {int? id, Decodable<T>? using}) → Stream<T>

Available on MappedDecoder, provided by the AsyncMappedDecoder extension

Decodes a Stream of T using the provided Decodable.
decodeStreamOrNull<T>(String key, {int? id, Decodable<T>? using}) → Stream<T>?

Available on MappedDecoder, provided by the AsyncMappedDecoder extension

Decodes a Stream of T or null using the provided Decodable.
decodeString(String key, {int? id}) → String
Decodes the data for the given key or id as a string value.
override
decodeStringOrNull(String key, {int? id}) → String?
Decodes the data for the given key or id as a nullable string value.
override
expect(String key, String expected, {int? id}) → Never
Throws an exception with a detailed message.
override
isHumanReadable() → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
whatsNext(String key, {int? id}) → DecodingType
Returns the actual or preferred DecodingType of the encoded data for the given key or id.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited